<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk_UA" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source> About Boomaga</source>
        <translation>Про програму</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Про</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation>Автори</translation>
    </message>
    <message>
        <source>Thanks</source>
        <translation>Подяки</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Переклади</translation>
    </message>
    <message>
        <source>Version: %1</source>
        <translation>Версія: %1</translation>
    </message>
    <message>
        <source>Boomaga provides a virtual printer for CUPS. This can be used for print preview or for print booklets.</source>
        <translation>Boomaga надає віртуальний притрер для CUPS, який може бути використаний для попереднього перегляду або друку книг. </translation>
    </message>
    <message>
        <source>Copyright: %1-%2 %3</source>
        <translation>Авторські права: %1-%2-%3</translation>
    </message>
    <message>
        <source>Homepage: %1</source>
        <translation>Домашня сторінка: %1</translation>
    </message>
    <message>
        <source>License: %1</source>
        <translation>Ліцензія: %1</translation>
    </message>
    <message>
        <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
        <translation>Хочете працювати з нашою командою розробників - &lt;a %1&gt;приєднуйтесь&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>Special thanks to:</source>
        <translation>Окрема подяка: </translation>
    </message>
    <message>
        <source>If you want to help translate, we will be glad to see you in our translation team on &lt;a %1&gt;Transifex server&lt;/a&gt;.</source>
        <translation> Якщо ви хочете допомогти з перекладом, ми будемо раді бачити вас в нашій команді перекладачів на сервері &lt;a %1&gt;Transifex&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>Boomaga is developed by the &lt;a %1&gt;Boomaga Team and contributors&lt;/a&gt; on GitHub.</source>
        <translation>Boomaga розробляється &lt;a %1&gt;Командою розробників Boomaga та сторонніми учасниками&lt;/a&gt; на GitHub.</translation>
    </message>
</context>
<context>
    <name>BooFile</name>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation>Не вдалося записати файл: &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Налаштування</translation>
    </message>
    <message>
        <source>Divide your long booklets into smaller sub-booklets for printing.</source>
        <translation>Розділяти під час друку велику книгу на невеликі зошити.</translation>
    </message>
    <message>
        <source>Print as sub-booklets</source>
        <translation>Друкувати з розбивкою на зошити</translation>
    </message>
    <message>
        <source>Maximum number of sheets in your sub-booklet.</source>
        <translation>Максимальна кількість листів у зошиті.</translation>
    </message>
    <message>
        <source>Sheets per sub-booklet:</source>
        <translation>Листів у зошиті:</translation>
    </message>
    <message>
        <source>Autosave your jobs every time you print.</source>
        <translation>Автоматично зберігати завдання після друку.</translation>
    </message>
    <message>
        <source>AutoSave the recent sessions</source>
        <translation>Автоматично зберігати сесії</translation>
    </message>
    <message>
        <source>Allow negative page margins:</source>
        <translation>Дозволяти від&apos;ємні поля</translation>
    </message>
    <message>
        <source>Select directory for saved jobs.</source>
        <translation>Виберіть директорію для збереження завдань.</translation>
    </message>
    <message>
        <source>Directory for saved sessions:</source>
        <translation>Директорія для збережених сесій:</translation>
    </message>
    <message>
        <source>Right-to-left direction</source>
        <translation>Розміщувати справа наліво</translation>
    </message>
</context>
<context>
    <name>CupsBooFile</name>
    <message>
        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
        <translation>Не вдалося прочитати файл: &quot;%1&quot;, файл зіпсовано або файли такого типу не підтримуються.</translation>
    </message>
</context>
<context>
    <name>ExportToPdf</name>
    <message>
        <source>Print to PDF</source>
        <translation>Друк у PDF</translation>
    </message>
    <message>
        <source>File name</source>
        <translation>Вихідний файл</translation>
    </message>
    <message>
        <source>Output file:</source>
        <translation>Назва:</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Meta info</source>
        <translation>Метадані</translation>
    </message>
    <message>
        <source>Author:</source>
        <translation>Автор:</translation>
    </message>
    <message>
        <source> The name of the person who created the document.</source>
        <translation>Ім&apos;я особи, що створила цей документ.</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Заголовок:</translation>
    </message>
    <message>
        <source>Subject:</source>
        <translation>Тема:</translation>
    </message>
    <message>
        <source> The subject of the document.</source>
        <translation>Тема документа.</translation>
    </message>
    <message>
        <source> Keywords associated with the document.</source>
        <translation>Ключові слова, пов&apos;язані зі змістом документа</translation>
    </message>
    <message>
        <source>Keywords:</source>
        <translation>Ключові слова:</translation>
    </message>
    <message>
        <source>PDF files (*.pdf);;All files (*.*)</source>
        <translation>PDF-файли (*.pdf);;Усі файли (*.*)</translation>
    </message>
    <message>
        <source>Overwrite file?</source>
        <translation>Перезаписати файл?</translation>
    </message>
    <message>
        <source>A file named &quot;%1&quot; already exists.
Are you sure you want to overwrite it?</source>
        <translation>Файл з іменем &quot;%1&quot; вже існує. 
Ви впевпевні, що хочете переписати його?</translation>
    </message>
    <message>
        <source> The document&apos;s title.</source>
        <translation>Заголовок документа.</translation>
    </message>
</context>
<context>
    <name>InFile</name>
    <message>
        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
        <translation>Не вдалося прочитати файл: &quot;%1&quot;, файл зіпсовано або файли такого типу не підтримуються.</translation>
    </message>
</context>
<context>
    <name>JobListView</name>
    <message>
        <source>%1 pages</source>
        <translation>%1 сторінок</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>&amp;Preferences</source>
        <translation>&amp;Налаштування</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Допомога</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Розташування</translation>
    </message>
    <message>
        <source>1 up</source>
        <translation>1 сторінка на аркуш</translation>
    </message>
    <message>
        <source>2 up</source>
        <translation>2 сторінки на аркуш</translation>
    </message>
    <message>
        <source>Booklet</source>
        <translation>Книгою</translation>
    </message>
    <message>
        <source>Print on both sides of a sheet.</source>
        <comment>MainForm::Double-sided checkbox tooltip</comment>
        <translation>Двосторонній друк</translation>
    </message>
    <message>
        <source>Double-sided</source>
        <comment>MainForm::Double-sided checkbox</comment>
        <translation>Двосторонній</translation>
    </message>
    <message>
        <source>Jobs</source>
        <translation>Завдання</translation>
    </message>
    <message>
        <source>Printer</source>
        <translation>Принтер</translation>
    </message>
    <message>
        <source>Configure...</source>
        <translation>Налаштувати...</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Панель інструментів</translation>
    </message>
    <message>
        <source>&amp;Print</source>
        <translation>&amp;Друк</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Ви&amp;хід</translation>
    </message>
    <message>
        <source>Print and Close</source>
        <translation>Друк і вихід</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>Next sheet</source>
        <translation>Наступний</translation>
    </message>
    <message>
        <source>Previous sheet</source>
        <translation>Попередній</translation>
    </message>
    <message>
        <source>About Boomaga</source>
        <translation>Про програму</translation>
    </message>
    <message>
        <source>Boomaga</source>
        <translation>Boomaga</translation>
    </message>
    <message>
        <source>%v of %m</source>
        <comment>Format for QProgressBar (http://qt-project.org/doc/qt-4.8/qprogressbar.html#format-prop)</comment>
        <translation>%v з %m</translation>
    </message>
    <message>
        <source>Print the all pages on %1.</source>
        <translation>Друкуються усі сторінки на %1</translation>
    </message>
    <message>
        <source>Print the odd pages on %1.&lt;p&gt;When finished, turn the pages, insert them into the printer&lt;br&gt;and click the Continue button.</source>
        <translation>Друкуються непарні сторінки на %1.&lt;p&gt;Після закінчення перегорніть стос паперу, вставте його в принтер&lt;br&gt; і  натисніть кнопку &quot;Продовжити&quot;.</translation>
    </message>
    <message>
        <source>Print the even pages on %1.</source>
        <translation>Друкуються парні сторінки на %1.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Продовжити</translation>
    </message>
    <message>
        <source>%1 pages</source>
        <comment>Status bar</comment>
        <translation>%1 сторінок</translation>
    </message>
    <message>
        <source>%1 page</source>
        <comment>Status bar</comment>
        <translation>%1 сторінка</translation>
    </message>
    <message>
        <source>%1 sheets</source>
        <comment>Status bar</comment>
        <translation>%1 аркуш.</translation>
    </message>
    <message>
        <source>%1 sheet</source>
        <comment>Status bar</comment>
        <translation>%1 аркуш</translation>
    </message>
    <message>
        <source>Sheet %1 of %2</source>
        <comment>Status bar</comment>
        <translation>Акруш %1 з %2</translation>
    </message>
    <message>
        <source>Insert blank page after this page</source>
        <translation>Вставити порожню сторінку після цієї</translation>
    </message>
    <message>
        <source>Delete this page</source>
        <translation>Видалити цю сторінку</translation>
    </message>
    <message>
        <source>Undo delete</source>
        <translation>Відмінити видалення</translation>
    </message>
    <message>
        <source>Insert blank page before this page</source>
        <translation>Вставити порошню сторінку перед цією</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
    <message>
        <source>Save project</source>
        <translation>Зберегти проект</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Save as...</source>
        <translation>Зберегти як...</translation>
    </message>
    <message>
        <source>Save project under a new name</source>
        <translation>Зберегти проект з новою назвою</translation>
    </message>
    <message>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Shift+S</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>Відкрити...</translation>
    </message>
    <message>
        <source>Open an existing project</source>
        <translation>Відкрити існуючий проект</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Page %1</source>
        <comment>'Undo deletion' menu item</comment>
        <translation>Сторінка %1</translation>
    </message>
    <message>
        <source>Boomaga files (*.boo);;All files (*.*)</source>
        <translation>Файли Boomaga(*.boo);;Усі файли (*.*)</translation>
    </message>
    <message>
        <source>Project saved successfully.</source>
        <translation>Проект збережено.</translation>
    </message>
    <message>
        <source>All supported files (*.pdf *.boo);;Boomaga files (*.boo);;PDF files (*.pdf);;All files (*.*)</source>
        <translation>Усі підтримувані файли (*.pdf *.boo);;Проект Boomaga (*.boo);;Документ PDF (*.pdf);;Усі файли (*.*)</translation>
    </message>
    <message>
        <source>4 up horizontal</source>
        <translation>4 стор. на аркуші горизонтально</translation>
    </message>
    <message>
        <source>4 up vertical</source>
        <translation>4 стор. на аркуші вертикально</translation>
    </message>
    <message>
        <source>8 up horizontal</source>
        <translation>8 стор. на аркуші горизонтально</translation>
    </message>
    <message>
        <source>8 up vertical</source>
        <translation>8 стор. на аркуші вертикально</translation>
    </message>
    <message>
        <source>Start new booklet from this page</source>
        <translation>Почати новий зошит з цієї сторінки</translation>
    </message>
    <message>
        <source>Don&apos;t start new booklet from this page</source>
        <translation>Не починати новий зошит з цієї сторінки</translation>
    </message>
    <message>
        <source>Rotate page to the left</source>
        <translation>Повернути сторінку проти годинникової стрілки</translation>
    </message>
    <message>
        <source>Rotate page to the right</source>
        <translation>Повернути сторінку за годинниковою стрілкою</translation>
    </message>
    <message>
        <source>Rename job</source>
        <translation>Перейменувати завдання</translation>
    </message>
    <message>
        <source>Rotate job to the left</source>
        <translation>Повернути завдання проти годинникової стрілки</translation>
    </message>
    <message>
        <source>Rotate job to the right</source>
        <translation>Повернути завдання за годинниковою стрілкою</translation>
    </message>
    <message>
        <source>Job title:</source>
        <translation>Назва завдання:</translation>
    </message>
    <message>
        <source>Export the project to PDF</source>
        <translation>Експортувати проект у PDF</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Clone job...</source>
        <translation>Клонувати завдання...</translation>
    </message>
    <message>
        <source>Clone job</source>
        <translation>Клонування завдання</translation>
    </message>
    <message>
        <source>Number of copies:</source>
        <translation>Кількість копій</translation>
    </message>
    <message>
        <source>Print with options...</source>
        <translation>Друк з заданням налаштувань...</translation>
    </message>
    <message>
        <source>Select number of copies before printing.</source>
        <translation>Вибір кількості копій до друку.</translation>
    </message>
    <message>
        <source>Ctrl+Shift+P</source>
        <translation>Ctrl+Shift+P</translation>
    </message>
    <message>
        <source>Sub-booklets</source>
        <translation>Зошити</translation>
    </message>
    <message>
        <source>Undo delete page</source>
        <translation>Відмінити видалення сторінок</translation>
    </message>
    <message>
        <source>Page %1 of %2</source>
        <comment>Status bar</comment>
        <translation>Стор. %1 з %2</translation>
    </message>
    <message>
        <source>Recent files</source>
        <translation>Останні файли</translation>
    </message>
    <message>
        <source>&amp;Edit page</source>
        <translation>Редагування &amp;сторінки</translation>
    </message>
    <message>
        <source>Edit &amp;job</source>
        <translation>Редагування &amp;завдання</translation>
    </message>
    <message>
        <source>&amp;Export to PDF...</source>
        <translation>&amp;Експорт у PDF...</translation>
    </message>
    <message>
        <source>Delete pages until the end of the job</source>
        <translation>Видалити сторінки до кінця завдання.</translation>
    </message>
    <message>
        <source>Delete current job</source>
        <translation>Видалити поточне завдання</translation>
    </message>
    <message>
        <source>Auto saving</source>
        <translation>Авто збереження</translation>
    </message>
    <message>
        <source>I can&apos;t create directory &quot;%1&quot;</source>
        <translation>Не вдалося створити директорію %1</translation>
    </message>
    <message>
        <source>%1 %2: Page %3</source>
        <comment>'Undo deletion' menu item, (%1 - is a job number, %2 - is a job title, %3 - is a page number in this job</comment>
        <translation>%1 %2: сторінка %3</translation>
    </message>
</context>
<context>
    <name>PostScriptFile</name>
    <message>
        <source>Converting PostScript to PDF</source>
        <comment>Progressbar text</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>I can&apos;t start gs converter: &quot;%1&quot;</source>
        <comment>Error message. 'gs' is a command line tool from ghostscript</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PrintDialog</name>
    <message>
        <source>Print document</source>
        <translation>Друк документа</translation>
    </message>
    <message>
        <source>Number of copies:</source>
        <translation>Кількість копій:</translation>
    </message>
    <message>
        <source>Collate copies:</source>
        <translation>Розібрати за копіями:</translation>
    </message>
</context>
<context>
    <name>PrinterSettings</name>
    <message>
        <source>Margins (mm)</source>
        <translation>Поля (мм)</translation>
    </message>
    <message>
        <source>Right:</source>
        <translation>Праве:</translation>
    </message>
    <message>
        <source>Bottom:</source>
        <translation>Нижнє:</translation>
    </message>
    <message>
        <source>Internal:</source>
        <translation>Внутрішнє:</translation>
    </message>
    <message>
        <source>Left:</source>
        <translation>Ліве:</translation>
    </message>
    <message>
        <source>Top:</source>
        <translation>Верхнє:</translation>
    </message>
    <message>
        <source>Draw border</source>
        <translation>Друкувати рамку</translation>
    </message>
    <message>
        <source>Print in reverse order</source>
        <translation>Друкувати в зворотньому порядку</translation>
    </message>
    <message>
        <source>Printer has duplexer</source>
        <translation>Дуплексний принтер</translation>
    </message>
    <message>
        <source>Manual with reverse (suitable for most printers)</source>
        <translation>Вручну зі зміною порядку (більшість принтерів)</translation>
    </message>
    <message>
        <source>Manual without reverse</source>
        <translation>Вручну без зміни порядку</translation>
    </message>
    <message>
        <source>Preferences of &quot;%1&quot;</source>
        <translation>Налаштування %1</translation>
    </message>
    <message>
        <source>Profiles</source>
        <translation>Профілі</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Reset to default</source>
        <translation>Скинути</translation>
    </message>
    <message>
        <source>Profile %1</source>
        <comment>Defaul name for created printer profile in the Printer Settings diaog</comment>
        <translation>Профіль: %1</translation>
    </message>
    <message>
        <source>Color mode:</source>
        <translation>Режим кольору:</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>За замовчуванням</translation>
    </message>
    <message>
        <source>Force grayscale</source>
        <translation>Чорно-білий друк</translation>
    </message>
    <message>
        <source>Force color</source>
        <translation>Кольоровий друк</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Налаштування</translation>
    </message>
    <message>
        <source>Print on both sides</source>
        <translation>Двосторонній друк</translation>
    </message>
    <message>
        <source>Flip on short edge</source>
        <translation>Оправа по короткій стороні</translation>
    </message>
    <message>
        <source>Flip on long edge</source>
        <translation>Оправа по довгій стороні</translation>
    </message>
</context>
<context>
    <name>Project</name>
    <message>
        <source>Boomaga</source>
        <comment>Error message title</comment>
        <translation>Boomaga</translation>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation>Не вдалос записати файл: &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>I can&apos;t read from file &apos;%1&apos;</source>
        <translation>Не вдалося прочитати файл: &quot;%1&quot;</translation>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation>Не вдалося записати файл: &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Без назви</translation>
    </message>
    <message>
        <source>Default</source>
        <comment>Printer profile default name</comment>
        <translation>За замовчуванням</translation>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot; (Empty file name)</source>
        <comment>Error message. %1 is a file name</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot; (No such file or directory)</source>
        <comment>Error message. %1 is a file name</comment>
        <translation>Не вдалося відкрити файл: &quot;%1&quot; (Немає такого файлу)</translation>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot; (Access denied)</source>
        <comment>Error message. %1 is a file name</comment>
        <translation>Не вдалося відкрити файл: &quot;%1&quot; (Немає прав доступу)</translation>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot;</source>
        <comment>Error message. %1 is a file name</comment>
        <translation>Не вдалося відкрити файл: &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>~/Untitled.pdf</source>
        <translation>~/Без_назви.pdf</translation>
    </message>
</context>
<context>
    <name>SubBookletView</name>
    <message>
        <source>Sub-booklet %1</source>
        <translation>Зошит %1</translation>
    </message>
    <message>
        <source>%1 pages</source>
        <translation>%1 сторінок</translation>
    </message>
</context>
<context>
    <name>TmpPdfFile</name>
    <message>
        <source>I can&apos;t create temporary file &quot;%1&quot;</source>
        <translation>Не вдалося створити тимчасовий файл: &quot;%1&quot;</translation>
    </message>
    <message>
        <source>I can&apos;t read file &apos;%1&apos;</source>
        <translation>Не вдалося прочитати файл: &quot;%1&quot;</translation>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation>Не вдалося записати файл: &quot;%1&quot;</translation>
    </message>
    <message>
        <source>I can&apos;t write file &quot;%1&quot;</source>
        <translation>Не вдалося записати файл: &quot;%1&quot;</translation>
    </message>
</context>
</TS>